# sosin: easy to use Python utils for general works

[![PyPI Latest Release](https://img.shields.io/pypi/v/sosin.svg)](https://pypi.org/project/sosin/)
[![License](https://img.shields.io/pypi/l/sosin.svg)](https://github.com/devsosin/sosin/blob/main/LICENSE)
[![Downloads](https://static.pepy.tech/personalized-badge/sosin?period=month&units=international_system&left_color=black&right_color=orange&left_text=PyPI%20downloads%20per%20month)](https://pepy.tech/project/sosin)

---

## Dependencies

![Python](https://img.shields.io/badge/python->=3.9-blue)
![MariaDB](https://img.shields.io/badge/MariaDB->=10.3-yellow)
![Chrome](https://img.shields.io/badge/Chrome--red)

## Installation

```bash
# PyPI
pip install sosin
```

## License

[MIT](LICENSE)

## Getting Help

For usage questions, Please contact [me](https://github.com/devsosin)
